######################################
######    Bssic information    #######
######################################


# R code for the article "Linguistic system and sociolinguistic environment as competing factors in linguistic variation: A typological approach"
# Submitted to the Journal of Historical Sociolinguistics
# Author: Kaius Sinnemäki
# Affiliation: University of Helsinki
# Date of last update: 4 June 2020



##################################
######    Preliminaries    #######
##################################


### Load necessary packages to R session
# If they are not installed yet, install them first
pkgs = c("readxl", "glmmADMB", "MuMIn", "sjPlot", "ggplot2")
install.packages(pkgs, repos = "https://cloud.r-project.org")

library(readxl)
library(glmmADMB)
library(MuMIn)
library(grid)
library(sjPlot)
library(ggplot2)


### Overdispersion
# The following function calculates overdispersion for GLMMs
# Author: Ben Bolker
# Source: http://bbolker.github.io/mixedmodels-misc/glmmFAQ.html
# Note that the rule of thumb (residual deviance/residual df) also clearly suggests overdispersion.

overdisp_fun <- function(model) {
  rdf <- df.residual(model)
  rp <- residuals(model,type="pearson")
  Pearson.chisq <- sum(rp^2)
  prat <- Pearson.chisq/rdf
  pval <- pchisq(Pearson.chisq, df=rdf, lower.tail=FALSE)
  c(chisq=Pearson.chisq,ratio=prat,rdf=rdf,p=pval)
}


### Read L1 data into the session
data.l1 <- read_excel("SupplementaryMaterial.xlsx", sheet = "L1_Data")

# Languages with "no case marking", value changed from WALS-value 1 to 0
data.l1$cases[data.l1$cases == 1] = 0

# Languages with borderline case marking analyzed as "no case-marking"
data.l1$cases[data.l1$cases == 9] = 0

# Extinct languages removed from the sample
data.l1 <- data.l1[!(data.l1$l1 %in% 0), ]

# Languages with fewer than 50 speakers analyzed as having 50 speakers
data.l1$l1_50 = data.l1$l1
data.l1$l1_50[data.l1$l1_50 <50] = 50

# Population size turned into a 10-based logarithm
data.l1$log_l1 = log10(data.l1$l1_50)

# Factorization of model variables
data.l1$family = as.factor(data.l1$family)
data.l1$area = as.factor(data.l1$area)
data.l1$wo = as.factor(data.l1$wo)

# Create the binary case-variable for binary models
data.l1$nz <- as.numeric(data.l1$cases>0)

# Number of sample languages
nrow(data.l1)

# VO order
data.l1$vo = data.l1$wo
levels(data.l1$vo)[c(1,2,5)] = "no"
levels(data.l1$vo)[2:3] = "yes"


### Read L2 data into R
data.l2 <- read_excel("SupplementaryMaterial.xlsx", sheet = "L2_Data")

# Languages with "no case marking", value changed from WALS-value 1 to 0
data.l2$cases[data.l2$cases == 1] = 0

# Languages with borderline case marking analyzed as "no case-marking"
data.l2$cases[data.l2$cases == 9] = 0

# Languages with fewer than 50 speakers analyzed as having 50 speakers
data.l2$l1_50 = data.l2$l1
data.l2$l1_50[data.l2$l1_50 <50] = 50

# Population size turned into a 10-based logarithm
data.l2$log_l1 = log10(data.l2$l1_50)

# Compute proportion of L2 speakers
data.l2$l2_prop = data.l2$l2/(data.l2$l1+data.l2$l2)

# Factorization of model variables
data.l2$family = as.factor(data.l2$family)
data.l2$area = as.factor(data.l2$area)
data.l2$wo = as.factor(data.l2$wo)

# Create the binary case-variable
data.l2$nz <- as.numeric(data.l2$cases>0)

# VO order
data.l2$vo = data.l2$wo
levels(data.l2$vo)[c(1,4)] = "no"
levels(data.l2$vo)[2:3] = "yes"

# Number of sample languages
nrow(data.l2)



##################################
####  CS1: L1 and word order  ####
##################################


### Create additive Poisson models
# Set the value for importance sampling. When setting the value of importance sampling, I tried different values, first using 0, 1, 10, 20, 50, 100,
# 200, and 300, and then trying values between these.

impsamp.cs1.po = 45

cs1.null.po <- glmmadmb(cases ~ 1 + (1+vo|family) + (1+log_l1|area),
                        data = data.l1, family="poisson", zeroInflation = T,
                        admb.opts = admbControl(impSamp = impsamp.cs1.po))
cs1.wo.po <- glmmadmb(cases ~ vo +  + (1+vo|family) + (1+log_l1|area),
                      data = data.l1, family="poisson", zeroInflation = T,
                      admb.opts = admbControl(impSamp = impsamp.cs1.po))
cs1.l1.po <- glmmadmb(cases ~ log_l1 +  + (1+vo|family) + (1+log_l1|area),
                      data = data.l1, family="poisson", zeroInflation = T,
                      admb.opts = admbControl(impSamp = impsamp.cs1.po))
cs1.noint.po <- glmmadmb(cases ~ vo + log_l1 +  + (1+vo|family) + (1+log_l1|area),
                      data = data.l1, family="poisson", zeroInflation = T,
                      admb.opts = admbControl(impSamp = impsamp.cs1.po))
cs1.int.po <- glmmadmb(cases ~ vo*log_l1 +  + (1+vo|family) + (1+log_l1|area),
                        data = data.l1, family="poisson", zeroInflation = T,
                        admb.opts = admbControl(impSamp = impsamp.cs1.po))

# Check for overdispersion. In all models p < 0.05. A Poisson model is thus not justified for the data. Negative binomial modelling used instead.
overdisp_fun(cs1.null.po)
overdisp_fun(cs1.wo.po)
overdisp_fun(cs1.l1.po)
overdisp_fun(cs1.noint.po)
overdisp_fun(cs1.int.po)


### Create additive negative binomial models
# Most random slopes produced random variances close to zero (1x10-7). For this reason I keep only random slope for vo over area.
# Set the value for importance sampling.
impsamp.cs1.negb = 36

cs1.null.negb <- glmmadmb(cases ~ 1 + (1|family) + (1+vo|area),
                        data = data.l1, family="nbinom", zeroInflation = T,
                        admb.opts = admbControl(impSamp = impsamp.cs1.negb))
cs1.wo.negb <- glmmadmb(cases ~ vo + (1|family) + (1+vo|area),
                      data = data.l1, family="nbinom", zeroInflation = T,
                      admb.opts = admbControl(impSamp = impsamp.cs1.negb))
cs1.l1.negb <- glmmadmb(cases ~ log_l1 + (1|family) + (1+vo|area),
                      data = data.l1, family="nbinom", zeroInflation = T,
                      admb.opts = admbControl(impSamp = impsamp.cs1.negb))
cs1.noint.negb <- glmmadmb(cases ~ log_l1 + vo + (1|family) + (1+vo|area),
                        data = data.l1, family="nbinom", zeroInflation = T,
                        admb.opts = admbControl(impSamp = impsamp.cs1.negb))
cs1.int.negb <- glmmadmb(cases ~ log_l1 * vo + (1|family) + (1+vo|area),
                         data = data.l1, family="nbinom", zeroInflation = T,
                         admb.opts = admbControl(impSamp = impsamp.cs1.negb))

# Likelihood ratios with anova
anova(cs1.null.negb, cs1.wo.negb)
anova(cs1.null.negb, cs1.l1.negb)
anova(cs1.wo.negb, cs1.noint.negb)
anova(cs1.noint.negb, cs1.int.negb)


### Akaike information criteria
# Compute the AICc values
aic.cs1.negb = AICc(cs1.null.negb, cs1.wo.negb, cs1.l1.negb, cs1.noint.negb, cs1.int.negb)

# Compute differences in AICc
aic.cs1.negb[,3] = c(NA, aic.cs1.negb[1,2]-aic.cs1.negb[2,2],
                aic.cs1.negb[1,2]-aic.cs1.negb[3,2],
                aic.cs1.negb[2,2]-aic.cs1.negb[4,2],
                aic.cs1.negb[4,2]-aic.cs1.negb[5,2])

# Compute AICc weights
aic.cs1.negb[,4] = Weights(aic.cs1.negb[,2])
colnames(aic.cs1.negb)[3:4] = c("AICc_diff", "Akaike weight")
aic.cs1.negb


# Summary statistics for the best-fitting model
summary(cs1.wo.negb)

# Computing the inverse logarithm and %-change
exp(coef(cs1.wo.negb))
(exp(coef(cs1.wo.negb))-1)*100


### Create addivite binomial models
# Set the value for importance sampling.
impsamp.cs1.bin = 25

cs1.null.bin <- glmmadmb(nz ~ 1 + (1+vo|family) + (1+log_l1+vo|area),
                           data = data.l1, family="binomial",
                           admb.opts = admbControl(impSamp = impsamp.cs1.bin))
cs1.wo.bin <- glmmadmb(nz ~ vo + (1+vo|family) + (1+log_l1+vo|area),
                         data = data.l1, family="binomial",
                         admb.opts = admbControl(impSamp = impsamp.cs1.bin))
cs1.l1.bin <- glmmadmb(nz ~ log_l1 + (1+vo|family) + (1+log_l1+vo|area),
                         data = data.l1, family="binomial",
                         admb.opts = admbControl(impSamp = impsamp.cs1.bin))
cs1.noint.bin <- glmmadmb(nz ~ vo + log_l1 + (1+vo|family) + (1+log_l1+vo|area),
                          data = data.l1, family="binomial",
                          admb.opts = admbControl(impSamp = impsamp.cs1.bin))
cs1.int.bin <- glmmadmb(nz ~ vo * log_l1 + (1+vo|family) + (1+log_l1+vo|area),
                        data = data.l1, family="binomial",
                        admb.opts = admbControl(impSamp = impsamp.cs1.bin))

# Likelihood ratios with anova
anova(cs1.null.bin, cs1.wo.bin)
anova(cs1.null.bin, cs1.l1.bin)
anova(cs1.wo.bin, cs1.noint.bin)
anova(cs1.noint.bin, cs1.int.bin)


### Akaike information criteria
# Compute the AICc values
aic.cs1.bin = AICc(cs1.null.bin, cs1.wo.bin, cs1.l1.bin, cs1.noint.bin, cs1.int.bin)

# Compute differences in AICc
aic.cs1.bin[,3] = c(NA, aic.cs1.bin[1,2]-aic.cs1.bin[2,2],
                    aic.cs1.bin[1,2]-aic.cs1.bin[3,2],
                    aic.cs1.bin[2,2]-aic.cs1.bin[4,2],
                    aic.cs1.bin[4,2]-aic.cs1.bin[5,2])

# Compute AICc weights
aic.cs1.bin[,4] = Weights(aic.cs1.bin[,2])
colnames(aic.cs1.bin)[3:4] = c("AICc_diff", "Akaike weight")
aic.cs1.bin


# Summary statistics for the best-fitting model
summary(cs1.int.bin)

# Computing the inverse logarithm and %-change
# for non-VO languages
exp(coef(cs1.int.bin)[3])
(exp(coef(cs1.int.bin)[3])-1)*100

# for VO-languages
sum(coef(cs1.int.bin)[3:4])
exp(sum(coef(cs1.int.bin)[3:4]))
(exp(sum(coef(cs1.int.bin)[3:4]))-1)*100



######################################
####  CS2: L1, L2 and word order  ####
######################################


### Create the additive Poisson models
# Models with random slopes were not used because of issues with convergence or too small variances.

# Set the value for importance sampling.
impsamp.cs2.po = 50

cs2.null.po <- glmmadmb(cases ~ 1 + (1|family) + (1|area),
                        data = data.l2, family="poisson", zeroInflation = T,
                        admb.opts = admbControl(impSamp = impsamp.cs2.po))
cs2.wo.po <- glmmadmb(cases ~ vo + (1|family) + (1|area),
                      data = data.l2, family="poisson", zeroInflation = T,
                      admb.opts = admbControl(impSamp = impsamp.cs2.po))
cs2.l2.po <- glmmadmb(cases ~ l2_prop + (1|family) + (1|area),
                      data = data.l2, family="poisson", zeroInflation = T,
                      admb.opts = admbControl(impSamp = impsamp.cs2.po))
cs2.l1.po <- glmmadmb(cases ~ log_l1 + (1|family) + (1|area),
                      data = data.l2, family="poisson", zeroInflation = T,
                      admb.opts = admbControl(impSamp = impsamp.cs2.po))
cs2.wol2.po <- glmmadmb(cases ~ vo + l2_prop + (1|family) + (1|area),
                      data = data.l2, family="poisson", zeroInflation = T,
                      admb.opts = admbControl(impSamp = impsamp.cs2.po))
cs2.main.po <- glmmadmb(cases ~ vo + l2_prop + log_l1 + (1|family) + (1|area),
                        data = data.l2, family="poisson", zeroInflation = T,
                        admb.opts = admbControl(impSamp = impsamp.cs2.po))

### Check for overdispersion. Because in all models p < 0.05, I used negative binomial models.
overdisp_fun(cs2.null.po)
overdisp_fun(cs2.wo.po)
overdisp_fun(cs2.l2.po)
overdisp_fun(cs2.l1.po)
overdisp_fun(cs2.wol2.po)
overdisp_fun(cs2.main.po)


### Create additive negative binomial models
# Models with random slopes were not used because of issues with convergence and too small random variances: only random intercept used.
# Set the value for importance sampling first
impsamp.cs2.negb = 2
cs2.null.negb <- glmmadmb(cases ~ 1 + (1|family) + (1|area),
                          data = data.l2, family="nbinom", zeroInflation = T,
                          admb.opts = admbControl(impSamp = impsamp.cs2.negb))
cs2.wo.negb <- glmmadmb(cases ~ vo + (1|family) + (1|area),
                        data = data.l2, family="nbinom", zeroInflation = T,
                        admb.opts = admbControl(impSamp = impsamp.cs2.negb))
cs2.l2.negb <- glmmadmb(cases ~ l2_prop + (1|family) + (1|area),
                        data = data.l2, family="nbinom", zeroInflation = T,
                        admb.opts = admbControl(impSamp = impsamp.cs2.negb))
cs2.l1.negb <- glmmadmb(cases ~ log_l1 + (1|family) + (1|area),
                        data = data.l2, family="nbinom", zeroInflation = T,
                        admb.opts = admbControl(impSamp = impsamp.cs2.negb))
cs2.wol2.negb <- glmmadmb(cases ~ vo + l2_prop + (1|family) + (1|area),
                        data = data.l2, family="nbinom", zeroInflation = T,
                        admb.opts = admbControl(impSamp = impsamp.cs2.negb))
cs2.main.negb <- glmmadmb(cases ~ vo + l2_prop + log_l1 + (1|family) + (1|area),
                          data = data.l2, family="nbinom", zeroInflation = T,
                          admb.opts = admbControl(impSamp = impsamp.cs2.negb))

# Likelihood ratios with anova
anova(cs2.null.negb, cs2.wo.negb)
anova(cs2.null.negb, cs2.l2.negb)
anova(cs2.null.negb, cs2.l1.negb)
anova(cs2.wo.negb, cs2.wol2.negb)
anova(cs2.wol2.negb, cs2.main.negb)


### Akaike information criteria

# Compute the AICc values
aic.cs2.negb = AICc(cs2.null.negb, cs2.wo.negb, cs2.l2.negb, cs2.l1.negb, cs2.wol2.negb, cs2.main.negb)

# Compute differences in AICc
aic.cs2.negb[,3] = c(NA, aic.cs2.negb[1,2]-aic.cs2.negb[2,2],
                   aic.cs2.negb[1,2]-aic.cs2.negb[3,2],
                   aic.cs2.negb[1,2]-aic.cs2.negb[4,2],
                   aic.cs2.negb[2,2]-aic.cs2.negb[5,2],
                   aic.cs2.negb[5,2]-aic.cs2.negb[6,2])

# Compute AICc weights
aic.cs2.negb[,4] = Weights(aic.cs2.negb[,2])
colnames(aic.cs2.negb)[3:4] = c("AICc_diff", "Akaike weight")
aic.cs2.negb


# Summary statistics for the best-fitting model
summary(cs2.l2.negb)

# Computing the inverse logarithm and %-change
exp(coef(cs2.l2.negb))
(exp(coef(cs2.l2.negb))-1)*100


### Models with interaction term between the predictors were not tested because of relatively small sample size.


### Create additive binary models
# Models with random slopes were not used because of issues with convergence and too small random variances: only random intercept used.
# Set the value for importance sampling first

# Set the value for importance sampling first
impsamp.cs2.bin = 1

cs2.null.bin <- glmmadmb(nz ~ 1 + (1|family) + (1|area),
                        data = data.l2, family="binomial",
                        admb.opts = admbControl(impSamp = impsamp.cs2.bin))
cs2.wo.bin <- glmmadmb(nz ~ vo + (1|family) + (1|area),
                      data = data.l2, family="binomial",
                      admb.opts = admbControl(impSamp = impsamp.cs2.bin))
cs2.l2.bin <- glmmadmb(nz ~ l2_prop + (1|family) + (1|area),
                      data = data.l2, family="binomial",
                      admb.opts = admbControl(impSamp = impsamp.cs2.bin))
cs2.l1.bin <- glmmadmb(nz ~ log_l1 + (1|family) + (1|area),
                       data = data.l2, family="binomial",
                       admb.opts = admbControl(impSamp = impsamp.cs2.bin))
cs2.wol2.bin <- glmmadmb(nz ~ vo+ l2_prop + (1|family) + (1|area),
                       data = data.l2, family="binomial",
                       admb.opts = admbControl(impSamp = impsamp.cs2.bin))
cs2.main.bin <- glmmadmb(nz ~ vo + l2_prop + log_l1 + (1|family) + (1|area),
                        data = data.l2, family="binomial",
                        admb.opts = admbControl(impSamp = impsamp.cs2.bin))

# Likelihood ratios with anova
anova(cs2.null.bin, cs2.wo.bin)
anova(cs2.null.bin, cs2.l2.bin)
anova(cs2.null.bin, cs2.l1.bin)
anova(cs2.wo.bin, cs2.wol2.bin)
anova(cs2.wol2.bin, cs2.main.bin)


### Akaike information criteria

# Compute the AICc values
aic.cs2.bin = AICc(cs2.null.bin, cs2.wo.bin, cs2.l2.bin, cs2.l1.bin, cs2.wol2.bin, cs2.main.bin)

# Compute differences in AICc
aic.cs2.bin[,3] = c(NA, aic.cs2.bin[1,2]-aic.cs2.bin[2,2],
                   aic.cs2.bin[1,2]-aic.cs2.bin[3,2],
                   aic.cs2.bin[1,2]-aic.cs2.bin[4,2],
                   aic.cs2.bin[3,2]-aic.cs2.bin[5,2],
                   aic.cs2.bin[5,2]-aic.cs2.bin[6,2])

# Compute AICc weights and print the AIC-table
aic.cs2.bin[,4] = Weights(aic.cs2.bin[,2])
colnames(aic.cs2.bin)[3:4] = c("AICc_diff", "Akaike weight")
aic.cs2.bin


# Summary statistics for the best-fitting model
summary(cs2.wol2.bin)

# Computing the inverse logarithm and %-change
exp(coef(cs2.wol2.bin))
(exp(coef(cs2.wol2.bin))-1)*100



###########################
######    Graphs    #######
###########################

# The code for setting the scale_x_continuous and scale_y_continuous in some of the figures was adapted from the discussion on tidyverse/ggplot2 at
#  github (https://github.com/tidyverse/ggplot2/issues/3296). Discussion was opened by daranzolin (https://github.com/daranzolin) and the solutions
#  I used were provided by aosmith16 (https://github.com/aosmith16).

# Some of the code for Figure 2 has been adapted from Bentz & Winter (2013) and the R code they provided online
#  (at http://www.bodowinter.com/cv.html; the R code is currently unavailable at the website).


### Figure 1
# Rename the feature values for word order
data.l1$wo_bp = data.l1$wo
levels(data.l1$wo_bp) = c("No dominant", "OVS", "SVO", "Verb-initial", "Verb-final")

# Create the boxplot
tiff(file="figure1.tif",res=150,units="mm",type="cairo",width=300,height=120)
grid.newpage()
grid.rect()
print(ggplot(data.l1, aes(x=wo_bp, y=cases)) + 
        geom_boxplot() + 
        labs(title="Number of cases per word order type",
             x="Word order", y = "Number of cases") +
        theme(text = element_text(size=20),
              axis.text.x = element_text(angle = 90, hjust = 1)) +
        scale_y_continuous(breaks = c(0,2,3,4,5,6,7,8),
                           labels = c("0","2","3","4","5","6-7","8-9","10+")),
      newpage=F)
dev.off()


### Figure 2: Histogram for the number of cases

tiff(file="figure2.tif",res=150,units="mm",type="cairo",width=300,height=100)
par(mai=c(0.8,0.8,0.3,0.8), mfrow=c(1,3))

# (A) Number of cases
hist(data.l1$cases, freq=F, xlim = c(0,8), ylab = "", xlab = "", yaxt = "n", main = "", xaxt="n")
axis(side=1,at=seq(0.5,7.5,by=1), labels=c("0", "2", "3", "4", "5", "6-7", "8-9", "10+"))
axis(side=2,at=seq(0,120,20)/254, labels=seq(0,120,20),xpd = TRUE)
axis(side=4,at=seq(0,0.49,0.05), labels=seq(0,0.49,0.05))
abline(h=0)
lines(density(data.l1$cases, bw="bcv")$x, density(data.l1$cases,bw="bcv")$y, lwd=2)
mtext(side=1,"Number of cases",cex=1.2,line=2.5)
mtext(side=2,"Frequency counts",cex=1,line=2.4)
text(x=7.1,y=0.45,"(A)",cex=1.25)

# (B) Population size
hist(data.l1$log_l1, freq=F, xlim = c(1, 10), breaks = seq(1.5,9.5,0.5), ylab = "", xlab = "", yaxt = "n", main = "")
axis(side=1,at=seq(1,10,by=1),labels=seq(1,10,by=1))
axis(side=2,at=seq(0,35,5)/127,labels=seq(0,35,5), xpd=T)
axis(side=4,at=seq(0,0.25,0.05),labels=seq(0,0.25,0.05), xpd = TRUE)
abline(h=0)
lines(density(data.l1$log_l1)$x, density(data.l1$log_l1)$y, lwd=2)
mtext(side=1,"Log (number of L1 speakers)",cex=1.2,line=2.5)
text(x=9.3,y=0.245,"(B)",cex=1.25)

# (C) Proportion of L2 speakers
hist(data.l2$l2_prop, freq=F, xlim = c(-0.05, 1.05), breaks = seq(-0.05,1.05,0.1), ylab = "", xlab = "", yaxt = "n", main = "")
axis(side=2,at=seq(0,14,2)/6.6,labels=seq(0,14,2),xpd = TRUE)
axis(side=4,at=seq(0,2.,0.25),labels=seq(0,2.,0.25), xpd = TRUE)
abline(h=0)
lines(density(data.l2$l2_prop)$x, density(data.l2$l2_prop)$y, lwd=2)
mtext(side=1,"Proportion of L2 speakers",cex=1.2,line=2.5)
mtext(side=4,"Density estimates",cex=1,line=2.4)
text(x=0.95,y=2.0,"(C)",cex=1.25)
dev.off()


### Figure 3: Plots for the best-fitting models in Case study 1
tiff(file="figure3.tif",res=150,units="mm",type="cairo",width=220,height=80)
grid.newpage()
pushViewport(viewport(layout = grid.layout(1, 2)))
pushViewport(viewport(layout.pos.col = 1, layout.pos.row = 1))
grid.rect()
print(plot_model(cs1.wo.negb, type = "eff", terms = "vo",
                 title = "Predicted counts for number of cases",
                 axis.title = c("Word order", "Number of cases"),
                 axis.lim=list(c("non-VO", "VO"),c(0,8))) +
        scale_y_continuous(breaks = c(0,2,4,6,8),
                           labels = c("0","2","4","6-7","10+"),
                           limits = c(0,8)) +
        labs(tag="A"),
      newpage=F)
upViewport()
pushViewport(viewport(layout.pos.col = 2, layout.pos.row = 1))
grid.rect()
print(plot_model(cs1.int.bin, type = "pred", terms = c("log_l1", "vo"),
                 axis.title = c("Log L1 speakers", "Probability of case"),
                 title = "Predicted probability of case",
                 show.data = T, legend.title = "VO order", color="bw") +
        scale_y_continuous(labels = paste(seq(0,100,by=20), "%"),
                           breaks = seq(0,1,by=0.2),
                           limits = c(0,1)) +
        scale_x_continuous(breaks = c(1,3,5,7,9)) +
        labs(tag="B"),
      newpage=F)
dev.off()


### Figure 4: Plots for the best-fitting models in Case study 2
tiff(file="figure4.tif",res=150,units="mm",type="cairo",width=220,height=140)
grid.newpage()
pushViewport(viewport(layout = grid.layout(2, 2)))
pushViewport(viewport(layout.pos.col = 1, layout.pos.row = 1))
grid.rect()
print(plot_model(cs2.l2.negb, type = "eff", terms = "l2_prop",
                 title = "Predicted counts for number of cases",
                 axis.title = c("Proportion of L2 speakers", "Number of cases"),
                 show.data = T, ci.lvl = F,
                 axis.lim=list(c(0.0,1.0),c(0,8.5))) +
        scale_y_continuous(breaks = c(0,2,4,6,8),
                           labels = c("0","2","4","6-7","10+"),
                           limits = c(0,8.5)) +
        scale_x_continuous(labels = paste(seq(0,100,by=20), "%"),
                           breaks = c(0,0.2,0.4,0.6,0.8,1)) +
        labs(tag="A"),
      newpage=F)
upViewport()
pushViewport(viewport(layout.pos.col = 2, layout.pos.row = 1))
grid.rect()
print(plot_model(cs2.wol2.bin, type = "eff", terms = "l2_prop",
                 title = "Predicted probability of case",
                 axis.title = c("Proportion of L2 speakers", "Probability of case"),
                 show.data = T, ci.lvl = F,
                 axis.lim=list(c(0.0,1.0),c(0,1))) +
        scale_y_continuous(labels = paste(seq(0,100,by=20), "%"),
                           breaks = seq(0,1,by=0.2),
                           limits = c(0,1)) +
        scale_x_continuous(labels = paste(seq(0,100,by=20), "%"),
                           breaks = c(0,0.2,0.4,0.6,0.8,1)) +
        labs(tag="B"),
      newpage=F)
upViewport()
pushViewport(viewport(layout.pos.col = 1, layout.pos.row = 2))
grid.rect()
print(plot_model(cs2.wol2.bin, type = "eff", terms = "vo",
                 title = "Predicted probability of case",
                 axis.title = c("Word order", "Probability of case"),
                 axis.lim=list(c("non-VO", "VO"),c(0,1))) +
        scale_y_continuous(labels = paste(seq(0,100,by=20), "%"),
                           breaks = seq(0,1,by=0.2),
                           limits = c(0,1)) +
        labs(tag="C"),
      newpage=F)
upViewport()
pushViewport(viewport(layout.pos.col = 2, layout.pos.row = 2))
grid.rect()
print(plot_model(cs2.wol2.bin, type = "pred", terms = c("l2_prop", "vo"),
                 axis.title = c("Proportion of L2 speakers", "Probability of case"),
                 title = "Predicted probability of case",
                 show.data = T, colors="bw",
                 legend.title = "VO order") +
        scale_y_continuous(labels = paste(seq(0,100,by=20), "%"),
                           breaks = seq(0,1,by=0.2),
                           limits = c(0,1)) +
        scale_x_continuous(labels = paste(seq(0,100,by=20), "%"),
                           breaks = c(0,0.2,0.4,0.6,0.8,1)) +
        labs(tag="D"),
      newpage=F)
dev.off()
